OC.L10N.register(
    "text",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
    "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
    "Missing a temporary folder" : "Et feelt en temporären Dossier",
    "Translate" : "Iwwersetzen",
    "guest" : "Gaascht",
    "Saved" : "Gespäichert",
    "Save changes" : "Ännerunge späicheren",
    "URL" : "URL",
    "to" : "bis",
    "Upload" : "Eroplueden",
    "Edit" : "Änneren",
    "Details" : "Detailer",
    "Choose" : "Auswielen",
    "Info" : "Info",
    "Warning" : "Warnung"
},
"nplurals=2; plural=(n != 1);");
